@@ -72,29 +72,26 @@ class SDK:
         if wait:
             while batch_rsp["status"] in ["PENDING", "RUNNING"]:
                 time.sleep(RESULT_POLLING_INTERVAL)
-                batch_rsp = self._client._get_batch(batch.id)
+                batch_rsp, _ = self._client._get_batch(batch.id)
             for job_id, job in batch.jobs.items():
                 job_rsp = self._client._get_job(job_id)
                 batch.jobs[job.id] = Job(**job_rsp)
         return batch
 
-    def get_batch(self, id: int, load_results: bool = False) -> Batch:
+    def get_batch(self, id: int, fetch_results: bool = False) -> Batch:
         """Retrieve a batch's data and all its jobs.
 
         Args:
             id: Id of the batch.
-            load_results: whether to load job results
+            fetch_results: whether to load job results
 
         Returns:
             Batch: the batch stored in the PCS database.
         """
 
-        batch_rsp = self._client._get_batch(id)
+        batch_rsp, jobs_rsp = self._client._get_batch(id, fetch_results=fetch_results)
         batch = Batch(**batch_rsp, _client=self._client)
-
-        job_rsp = self._client._get_jobs(id, fetch_results=load_results)
-        for job in job_rsp:
-            batch.jobs[job["id"]] = Job(**job)
-
+        for job_rsp in jobs_rsp:
+            batch.jobs[job_rsp["id"]] = Job(**job_rsp)
         self.batches[batch.id] = batch
         return batch
